pub struct Delay;
Type implementing async delays and blocking embedded-hal delays.

The delays are implemented in a “best-effort” way, meaning that the cpu will block for at least the amount provided, but accuracy can be affected by many factors, including interrupt usage. Make sure to use a suitable tick rate for your use case. The tick rate is defined by the currently active driver.