pub struct Duration { /* private fields */ }
Represents the difference between two Instants

Implementations

The smallest value that can be represented by the Duration type.

The largest value that can be represented by the Duration type.

Tick count of the Duration.

Convert the Duration to seconds, rounding down.

Convert the Duration to milliseconds, rounding down.

Convert the Duration to microseconds, rounding down.

Creates a duration from the specified number of clock ticks

Creates a duration from the specified number of seconds, rounding up.

Creates a duration from the specified number of milliseconds, rounding up.

Creates a duration from the specified number of microseconds, rounding up. NOTE: Delays this small may be inaccurate.

Creates a duration from the specified number of seconds, rounding down.

Creates a duration from the specified number of milliseconds, rounding down.

Creates a duration from the specified number of microseconds, rounding down. NOTE: Delays this small may be inaccurate.

Adds one Duration to another, returning a new Duration or None in the event of an overflow.

Subtracts one Duration to another, returning a new Duration or None in the event of an overflow.

Multiplies one Duration by a scalar u32, returning a new Duration or None in the event of an overflow.

Divides one Duration a scalar u32, returning a new Duration or None in the event of an overflow.