Struct embassy_time::Duration
source · [−]pub struct Duration { /* private fields */ }Expand description
Represents the difference between two Instants
Implementations
sourceimpl Duration
impl Duration
sourcepub const fn from_ticks(ticks: u64) -> Duration
pub const fn from_ticks(ticks: u64) -> Duration
Creates a duration from the specified number of clock ticks
sourcepub const fn from_secs(secs: u64) -> Duration
pub const fn from_secs(secs: u64) -> Duration
Creates a duration from the specified number of seconds, rounding up.
sourcepub const fn from_millis(millis: u64) -> Duration
pub const fn from_millis(millis: u64) -> Duration
Creates a duration from the specified number of milliseconds, rounding up.
sourcepub const fn from_micros(micros: u64) -> Duration
pub const fn from_micros(micros: u64) -> Duration
Creates a duration from the specified number of microseconds, rounding up. NOTE: Delays this small may be inaccurate.
sourcepub const fn from_secs_floor(secs: u64) -> Duration
pub const fn from_secs_floor(secs: u64) -> Duration
Creates a duration from the specified number of seconds, rounding down.
sourcepub const fn from_millis_floor(millis: u64) -> Duration
pub const fn from_millis_floor(millis: u64) -> Duration
Creates a duration from the specified number of milliseconds, rounding down.
sourcepub const fn from_micros_floor(micros: u64) -> Duration
pub const fn from_micros_floor(micros: u64) -> Duration
Creates a duration from the specified number of microseconds, rounding down. NOTE: Delays this small may be inaccurate.
sourcepub fn checked_add(self, rhs: Duration) -> Option<Duration>
pub fn checked_add(self, rhs: Duration) -> Option<Duration>
Adds one Duration to another, returning a new Duration or None in the event of an overflow.
sourcepub fn checked_sub(self, rhs: Duration) -> Option<Duration>
pub fn checked_sub(self, rhs: Duration) -> Option<Duration>
Subtracts one Duration to another, returning a new Duration or None in the event of an overflow.
sourcepub fn checked_mul(self, rhs: u32) -> Option<Duration>
pub fn checked_mul(self, rhs: u32) -> Option<Duration>
Multiplies one Duration by a scalar u32, returning a new Duration or None in the event of an overflow.
sourcepub fn checked_div(self, rhs: u32) -> Option<Duration>
pub fn checked_div(self, rhs: u32) -> Option<Duration>
Divides one Duration a scalar u32, returning a new Duration or None in the event of an overflow.