Struct embassy_time::Ticker
source · [−]pub struct Ticker { /* private fields */ }Expand description
Asynchronous stream that yields every Duration, indefinitely.
This stream will tick at uniform intervals, even if blocking work is performed between ticks.
For instance, consider the following code fragment.
use embassy_time::{Duration, Timer};
#[embassy_executor::task]
async fn ticker_example_0() {
loop {
foo();
Timer::after(Duration::from_secs(1)).await;
}
}This fragment will not call foo every second.
Instead, it will call it every second + the time it took to previously call foo.
Example using ticker, which will consistently call foo once a second.
use embassy_time::{Duration, Ticker};
use futures::StreamExt;
#[embassy_executor::task]
async fn ticker_example_1() {
let mut ticker = Ticker::every(Duration::from_secs(1));
loop {
foo();
ticker.next().await;
}
}Implementations